Welcome to Snakecdysis documentation!
=====================================


.. image:: ./_images/Snakecdysis_logo.png
   :target: ./_images/Snakecdysis_logo.png
   :alt: Snakecdysis Logo

About this package
------------------

.. automodule:: snakecdysis
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

.. toctree::
   :caption: Installation
   :name: install
   :maxdepth: 5

   ./install
   ./package


.. toctree::
   :caption: Package documentation
   :name: module
   :maxdepth: 6

   ./snakecdysis
   ./workflow

.. toctree::
   :caption: Useful functions
   :name: useful
   :maxdepth: 4

   ./usefulfunctions

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
